# *******************************************************************
# **  @file eisman_inc.awk - global set of definitions and functions
# **
# **  Creation:     2018-12-27 dv
# **  Last update:  $Id: eisman_inc.awk 65928 2019-06-09 17:30:39Z dv $
# **
# **  Copyright (c) 2013-2019 the eisfair team, team(at)eisfair(dot)org
# **
# **  This program is free software; you can redistribute it and/or modify
# **  it under the terms of the GNU General Public License as published by
# **  the Free Software Foundation; either version 2 of the License, or
# **  (at your option) any later version.
# *******************************************************************

@include "eisman_inc_types.awk"
@include "eisman_inc_system.awk"
@include "eisman_inc_console.awk"


# *******************************************************************
# entry function of awk script
# *******************************************************************

BEGIN {
    eisman_path         = "/var/lib/eisman";
    eisman_bin_path     = "/usr/share/eisman";
    eisman_awk_bin_path = eisman_bin_path "/awk";
    eisman_noarch       = "eisfair-noarch";
    eisman_system       = get_system_tag();
    eisman_separator    = "---------------------------------------------------------";
    eisman_labelsize    = 11;
    eisman_db_version   = "1.2";
}


# *******************************************************************
# **  return eisfair system tag
# **  @param  n/a
# **  @return system tag
# *******************************************************************

function get_system_tag(    \
    command,
    result)
{
    command = "lsb_release -ds";

    command |& getline result;
    close(command);

    return result;
}


# *******************************************************************
# **  strip filename and php call parameters from url, so that only the
# **  static part remains.
# **  @param  url  full qualified URL to a package resource
# **  @return static part of the URL without file name
# *******************************************************************

function get_base_url(url,    \
    idx)
{
    # remove php arguments
    idx = index(url, "?");
    if (idx > 0)
    {
        url = substr(url, 1, idx - 1);
    }

    # remove file name
    idx = match(url, /\/[^\/]*$/);
    if (idx > 0)
    {
        url = substr(url, 1, idx - 1);
    }

    # remove numeric sub folder
    idx = match(url, /\/[0-9]*$/);
    if (idx > 0)
    {
        url = substr(url, 1, idx - 1);
    }

    return url;
}
