# *******************************************************************
# **  @file eisman_inc_query.awk - package query function
# **
# **  Creation:     2018-12-27 dv
# **  Last update:  $Id: eisman_inc_query.awk 64790 2019-04-30 20:28:33Z dv $
# **
# **  Copyright (c) 2013-2019 the eisfair team, team(at)eisfair(dot)org
# **
# **  This program is free software; you can redistribute it and/or modify
# **  it under the terms of the GNU General Public License as published by
# **  the Free Software Foundation; either version 2 of the License, or
# **  (at your option) any later version.
# *******************************************************************

@include "eisman_inc.awk"


# *******************************************************************
# **  use grep to perform a query on the package.db file.
# **  @param[in]  inc_sections   list of sections Form "section1|section2..."
# **                         (can be an empty string!)
# **  @param[in]  excl_sections  list of sections to exclude
# **                         (can be an empty string!)
# **  @param[in]  packages       list of packages to search for
# **                         (can be an empty string!)
# **  @param[in]  versions  version (can be an empty string!)
# **  @param[in]  state     package state (can be an empty string!)
# **  @param[in]  url       url (can be an empty string!)
# **  @param[in]  fields    list of fields
# **  @param[in]  database  database to query from
# **  @param[out] records   record array
# **  @return number of records found
# *******************************************************************

function query_package_db(inc_sections, excl_sections, packages, versions,
                          state, url, fields, database, records,    \
    command,
    idx,
    replaces_cnt,
    require_cnt,
    link_cnt,
    text_cnt)
{
    if (inc_sections == "")
    {
        inc_sections = ".*";
    }

    if (packages == "")
    {
        packages = ".*";
    }

    if (versions == "")
    {
        versions = ".*";
    }

    if (state == "")
    {
        state = ".*";
    }

    if (url == "")
    {
        url = ".*";
    }

    if (fields == "")
    {
        fields = ".*";
    }

    if (excl_sections == "")
    {
        command = "grep -E \"^\\[(" inc_sections     \
                            ")\\]\\[(" packages      \
                            ")\\]\\[(" versions      \
                            ")\\]\\["  state         \
                            "\\]\\[" url             \
                            "\\](" fields "|record|-------" \
                            ")[-| ]\" " database     \
                  " | cut  -d ']' -f 6- "            \
                  " | sed -e ':a;N;$!ba;s/\\n/||/g'" \
                  "       -e 's/||" eisman_separator "||/||" eisman_separator "\\n/g'" \
                  " | sort "                         \
                  " | sed 's/||/\\n/g'";
    }
    else
    {
        command = "grep -E \"^\\[(" inc_sections     \
                            ")\\]\\[(" packages      \
                            ")\\]\\[(" versions      \
                            ")\\]\\["  state         \
                            "\\]\\[" url             \
                            "\\](" fields "|record|-------" \
                            ")[-| ]\" " database     \
                  " | grep -v -E \"^\\[(" excl_sections ")\\]\"" \
                  " | cut  -d ']' -f 6- "             \
                  " | sed -e ':a;N;$!ba;s/\\n/||/g'"  \
                  "       -e 's/||" eisman_separator "||/||" eisman_separator "\\n/g'" \
                  " | sort "                       \
                  " | sed 's/||/\\n/g'";
    }

    idx = 1;
    while ((command |& getline line) > 0)
    {
        label = substr(line, 1, eisman_labelsize);
        line  = substr(line, eisman_labelsize + 1);

        if (label == "-----------")
        {
            idx++;
            replaces_cnt = 0;
            require_cnt  = 0;
            link_cnt     = 0;
            text_cnt     = 0;
        }
        else
        {
            gsub(/ /, "", label);

            switch(label)
            {
            case "replaces":
                records[idx][label][++replaces_cnt] = line;
                break;

            case "require":
                records[idx][label][++require_cnt] = line;
                break;

            case "link":
                records[idx][label][++link_cnt] = line;
                break;

            case "text":
                records[idx][label][++text_cnt] = line;
                break;

            case "exclude":
                records[idx][label][++text_cnt] = line;
                break;

            default:
                records[idx][label] = line;
                break;
            }
        }
    }
    close(command);

    return (idx - 1);
}


# *******************************************************************
# **  show a vertical list of packages.
# **  @param  packages  package list is two-dimensional array
# **  @return n/a
# *******************************************************************

function list_packages(packages,   \
    tablefields,
    rec_idx,
    field_idx,
    sub_idx)
{
    tablefields[1]  = "name";
    tablefields[2]  = "version";
    tablefields[3]  = "short";
    tablefields[4]  = "date";
    tablefields[5]  = "author";
    tablefields[6]  = "section";
    tablefields[7]  = "space";
    tablefields[8]  = "sha1sum";
    tablefields[9]  = "sha256sum";
    tablefields[10] = "url";
    tablefields[11] = "status";
    tablefields[12] = "replaces";
    tablefields[13] = "require";
    tablefields[14] = "link";
    tablefields[15] = "text";
    tablefields[16] = "hint";
    tablefields[17] = "substitude";

    for (rec_idx in packages)
    {
        for (field_idx in tablefields)
        {
            if (tablefields[field_idx] in packages[rec_idx])
            {
                if (typeof(packages[rec_idx][tablefields[field_idx]]) != "array")
                {
                    printf("%s%s%-11s%s%s\n",
                        con_text_color_green,
                        con_bkgnd_color_default,
                        tablefields[field_idx],
                        con_text_color_default,
                        packages[rec_idx][tablefields[field_idx]]);
                }
                else
                {
                    for (sub_idx in packages[rec_idx][tablefields[field_idx]])
                    {
                        printf("%s%s%-11s%s%s\n",
                            con_text_color_green,
                            con_bkgnd_color_default,
                            tablefields[field_idx],
                            con_text_color_default,
                            packages[rec_idx][tablefields[field_idx]][sub_idx]);
                    }
                }
            }
        }
        print "---------------------------------------------------------";
    }
}

