# *******************************************************************
# **  @file eisman_inc_system.awk - wrapper functions for system calls
# **
# **  Creation:     2018-12-27 dv
# **  Last update:  $Id: eisman_inc_system.awk 65952 2019-06-10 09:04:02Z dv $
# **
# **  Copyright (c) 2013-2019 the eisfair team, team(at)eisfair(dot)org
# **
# **  This program is free software; you can redistribute it and/or modify
# **  it under the terms of the GNU General Public License as published by
# **  the Free Software Foundation; either version 2 of the License, or
# **  (at your option) any later version.
# *******************************************************************

@include "eisman_inc_types.awk"


function mkdir(path,   res)
{
    res = system("mkdir -p " path);
    if (res)
    {
        return false;
    }
    return true;
}


function rmdir(path,   res)
{
    res = system("rmdir -p " path " 2> /dev/tmp");
    if (res)
    {
        return false;
    }
    return true;
}


function remove(path,   res)
{
    res = system("rm -f " path);
    if (res)
    {
        return false;
    }
    return true;
}


function rename(path1, path2,   res)
{
    res = system("mv " path1 " " path2);
    if (res)
    {
        return false;
    }
    return true;
}


function copy(path1, path2,   res)
{
    res = system("cp " path1 " " path2);
    if (res)
    {
        return false;
    }
    return true;
}


function touch(path,   files, idx, count, res)
{
    if (path != "")
    {
        split(path, files, " ");

        path = "";
        count = 0;
        for (idx in files)
        {
            path = path " " files[idx];
            count++;
            if (count > 500)
            {
                res = system("touch " path);
                if (res)
                {
                    return false;
                }
                count = 0;
                path = "";
            }
        }
        if (count > 0)
        {
            res = system("touch " path);
            if (res)
            {
                return false;
            }
        }
    }
    return true;
}


function file_exists(file,   tmp)
{
    if ((getline tmp < file) >= 0)
    {
        close(file)
        return true;
    }
    else
    {
        return false;
    }
}


function get_file_encoding(file,  command, result)
{
    command = "file -b --mime-encoding " file;

    command |& getline result;
    close(command);

    return result;
}


function find_files(files, path, arguments,    command, line, idx)
{
    command = "find " path " " arguments " 2> /dev/null";

    idx = 0;
    while ((command |& getline line) > 0)
    {
        files[++idx] = line;
    }
    close(command);

    return idx;
}


function basename(name,   result, idx)
{
   idx = match(name, /\/[^\/]*$/);
   if (idx > 0)
   {
       result = substr(name, idx + 1);
       return result;
   }
   return name;
}


function dirname(name,   result, idx)
{
   idx = match(name, /\/[^\/]*$/);
   if (idx > 0)
   {
       if (idx > 1)
       {
           result = substr(name, 1, idx - 1);
       }
       else
       {
           result = substr(name, 1, idx);
       }
       return result;
   }
   return name;
}


function exec_command(command,  \
    exitcode)
{
    exitcode = system(command);
    if (exitcode >= 256)
    {
        # command has been killed by a signal! therefore we
        # exit as well passing the full 16-bit exit code to the caller
        exit(exitcode);
    }

    return exitcode;
}


function sleep(secs)
{
    exec_command("sleep " secs);
}


function get_kernel_name(   result)
{
    command = "uname -r | gawk -F'-' '{ print tolower($NF) }'";

    command |& getline result;
    close(command);

    return "eiskernel-" result;
}
