# *******************************************************************
# **  @file eisman_query.awk - query package databases
# **
# **  Creation:     2019-02-17 dv
# **  Last update:  $Id: eisman_query.awk 64770 2019-04-26 21:54:56Z dv $
# **
# **  Copyright (c) 2019-2019 the eisfair team, team(at)eisfair(dot)org
# **
# **  This program is free software; you can redistribute it and/or modify
# **  it under the terms of the GNU General Public License as published by
# **  the Free Software Foundation; either version 2 of the License, or
# **  (at your option) any later version.
# *******************************************************************

@include "eisman_inc.awk"
@include "eisman_inc_query.awk"


# *******************************************************************
# entry function of awk script
# *******************************************************************

BEGIN {
    # if list of fields is empty, set standard fields, else
    # replace commas with pipe characters
    if (fields == "")
    {
        fields = "name|short|status|version|url|date";
    }
    else
    {
        fields = gensub(/,/, "|", "g", fields);
    }

    # if list of include sections is empty, include all secions but
    # hidden ones, else replace commas with pipe characters
    if (incl_sections == "")
    {
        incl_sections = "[^.].*";
    }
    else
    {
        incl_sections = gensub(/,/, "|", "g", incl_sections);
    }

    # if list of excluded sections is not empty, replace commas with
    # pipe characters
    if (excl_sections != "")
    {
        excl_sections = gensub(/,/, "|", "g", excl_sections);
    }

    # if packages are given, replace wildcard placeholders and commas
    if (packages != "")
    {
        packages = gensub(/\*/, ".*", "g", packages);
        packages = gensub(/\?/, ".",  "g", packages);
        packages = gensub(/,/,  "|",  "g", packages);
    }

    # set default database if empty
    if (database == "")
    {
        database = eisman_path "/packages.db";
    }

    # now query for all packages
    count = query_package_db( \
        incl_sections,
        excl_sections,
        packages,
        version,
        state,
        url_filter,
        fields,
        database,
        record);
    if (count > 0)
    {
        list_packages(record);
        exit(0);
    }
    exit(1);
}

