#!/bin/bash
# *******************************************************************
# **  @file eisman_tree.sh - resolve requirement tree
# **
# **  Creation:     2013-01-13 dv
# **  Last update:  $Id: eisman_tree.sh 64676 2019-04-22 17:43:36Z hbfl $
# **
# **  Copyright (c) 2013-2019 the eisfair team, team(at)eisfair(dot)org
# **
# **  This program is free software; you can redistribute it and/or modify
# **  it under the terms of the GNU General Public License as published by
# **  the Free Software Foundation; either version 2 of the License, or
# **  (at your option) any later version.
# *******************************************************************

. /var/install/include/eislib
. /var/install/include/eismanlib

gawk=/usr/bin/gawk

# *******************************************************************
# **  main program
# *******************************************************************
main()
{
    local unstable="no"
    local url=""

    # read option switches
    while [ "${1:0:2}" = "--" ]
    do
        case ${1} in
        --unstable)
            unstable="yes"
            shift
            ;;
        --url)
            shift
            url="${1}"
            shift
            ;;
        --url=*)
            url="${1:6}"
            shift
            ;;
        *)
            echo "error: invalid switch \"${1}\"!" >&2
            ;;
        esac
    done

    # read package list from command line
    while [ "$#" -gt "0" ]
    do
        packages="${packages} ${1}"
        shift
    done

    # set include path for awk scripts
    export AWKPATH="${EISMAN_BIN_PATH}/awk"

    ${gawk} -v unstable="${unstable}"           \
            -v url="${url}"                     \
            -v packages="${packages}"           \
            -f "${EISMAN_BIN_PATH}/awk/eisman_tree.awk"

    exit ${?}
}

main "${@}"
