#!/bin/bash
# *******************************************************************
# **  @file eisman_update.sh - update local package database
# **
# **  Creation:     2013-01-12 dv
# **  Last update:  $Id: eisman_update.sh 64378 2019-04-14 18:35:42Z dv $
# **
# **  Copyright (c) 2013-2019 the eisfair team, team(at)eisfair(dot)org
# **
# **  This program is free software; you can redistribute it and/or modify
# **  it under the terms of the GNU General Public License as published by
# **  the Free Software Foundation; either version 2 of the License, or
# **  (at your option) any later version.
# *******************************************************************

. /var/install/include/eislib
. /var/install/include/eismanlib

gawk=/usr/bin/gawk

# *******************************************************************
# **  show help on arguments and possible options
# **  @param  n/a
# **  @return n/a
# *******************************************************************

show_help()
{
cat <<EOF

Update local package database

usage:
    eisman update [OPTIONS]

options:
    --help            show this help screen
    --no-progress     don't show progress information.
    --no-tty          don't use escape sequences for cursor movement
                      and color output. Also disables progress
                      information (--no-progress).
    --quiet           no text output as long as no new packages are
                      being fetched. Also disables progress information
                      (--no-progress).

EOF
}


# *******************************************************************
# **  main script
# **  @param  n/a
# **  @return n/a
# *******************************************************************

main()
{
    local progress='yes'
    local is_tty='yes'
    local quiet='no'

    while [ "${1:0:2}" = "--" ]
    do
        case ${1} in
        --help)
            show_help
            exit 0
            ;;
        --quiet)
            quiet='yes'
            progress='no'
            shift
            ;;
        --no-progress)
            progress='no'
            shift
            ;;
        --no-tty)
            is_tty='no'
            progress='no'
            shift
            ;;
        *)
            echo "error: unknown option \"${1}\"!" >&2
            echo
            show_help
            exit 1
        esac
    done

    if [ "$#" -gt 0 ]
    then
        echo 'error: invalid number of arguments!' >&2
        echo
        show_help
        exit 1
    fi

    # set include path for awk scripts
    export AWKPATH="${EISMAN_BIN_PATH}/awk"

    # call awk script
    ${gawk} -v progress=${progress} \
            -v quiet=${quiet}     \
            -v is_tty=${is_tty}   \
            -v color=${is_tty}    \
            -f "${EISMAN_BIN_PATH}/awk/eisman_update.awk"
}

main "${@}"
